==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebForOfDataChangingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebForOfDataChangingEventArgsDetailDescriptionMetadata } from "./WebForOfDataChangingEventArgsDetailDescriptionMetadata";
import { WebForOfDataChangingEventArgsDescription } from "./WebForOfDataChangingEventArgsDescription";
/**
 * @hidden
 */
export let WebForOfDataChangingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebForOfDataChangingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebForOfDataChangingEventArgsDescriptionMetadata.a == null) {
                WebForOfDataChangingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebForOfDataChangingEventArgsDescriptionMetadata.c(WebForOfDataChangingEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebForOfDataChangingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebForOfDataChangingEventArgsDescriptionMetadata.a);
            WebForOfDataChangingEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ForOfDataChangingEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("Detail", "ExportedType:WebForOfDataChangingEventArgsDetail");
        }
        static d(a) {
            WebForOfDataChangingEventArgsDescriptionMetadata.b(a);
            a.aa("WebForOfDataChangingEventArgs", () => new WebForOfDataChangingEventArgsDescription());
            a.z("WebForOfDataChangingEventArgs", WebForOfDataChangingEventArgsDescriptionMetadata.a);
        }
    }
    WebForOfDataChangingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebForOfDataChangingEventArgsDescriptionMetadata, 'WebForOfDataChangingEventArgsDescriptionMetadata');
    WebForOfDataChangingEventArgsDescriptionMetadata.a = null;
    return WebForOfDataChangingEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebForOfDataChangingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebForOfDataChangingEventArgsDetailDescriptionMetadata } from "./WebForOfDataChangingEventArgsDetailDescriptionMetadata";
import { WebForOfDataChangingEventArgsDescription } from "./WebForOfDataChangingEventArgsDescription";
/**
 * @hidden
 */
export let WebForOfDataChangingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebForOfDataChangingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebForOfDataChangingEventArgsDescriptionMetadata.a == null) {
                WebForOfDataChangingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebForOfDataChangingEventArgsDescriptionMetadata.c(WebForOfDataChangingEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebForOfDataChangingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebForOfDataChangingEventArgsDescriptionMetadata.a);
            WebForOfDataChangingEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ForOfDataChangingEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebForOfDataChangingEventArgsDetail");
        }
        static d(a) {
            WebForOfDataChangingEventArgsDescriptionMetadata.b(a);
            a.ac("WebForOfDataChangingEventArgs", () => new WebForOfDataChangingEventArgsDescription());
            a.ab("WebForOfDataChangingEventArgs", WebForOfDataChangingEventArgsDescriptionMetadata.a);
        }
    }
    WebForOfDataChangingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebForOfDataChangingEventArgsDescriptionMetadata, 'WebForOfDataChangingEventArgsDescriptionMetadata');
    WebForOfDataChangingEventArgsDescriptionMetadata.a = null;
    return WebForOfDataChangingEventArgsDescriptionMetadata;
})();
